#!/bin/sh
# Oxygen License Server startup script

startLicenseServer() {
# Resolve the location of the installation.
# This includes resolving any symlinks.
PRG=$0
while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
    if expr "$link" : '^/' 2> /dev/null >/dev/null; then
        PRG="$link"
    else
        PRG="`dirname "$PRG"`/$link"
    fi
done

OXYGEN_HOME=`dirname "$PRG"`

# Absolutize dir
cd "${OXYGEN_HOME}"

OXYGEN_JAVA=java
if [ -f "${JAVA_HOME}/bin/java" ]
then
  OXYGEN_JAVA="${JAVA_HOME}/bin/java"
fi
if [ -f "${OXYGEN_HOME}/jre/bin/java" ]
then
  OXYGEN_JAVA="${OXYGEN_HOME}/jre/bin/java"
fi

# This is the command line for the license server.
CMDLINE="-cp .:oxygenLicenseServer.jar:activation-system-id.jar:commons-codec-1.10.jar:log4j.jar ro.sync.licensemanager.server.LicenseServer"

# This is the directory where the license files are located. 
# Default location (if this param is missing) is ./license
LICENSEDIR=$1

# This is the port to connect to.
# If this param is missing, the default value is 	12346
PORT=$2

if [ "$LICENSEDIR" != "" ]; then
  CMDLINE=$CMDLINE" -licenseDir $LICENSEDIR"
fi
if [ "$PORT" != "" ]; then
  CMDLINE=$CMDLINE" -port $PORT"
fi

# Start the server.
exec "${OXYGEN_JAVA}" ${CMDLINE}
}

showUsage() {
echo ------- 
echo -e "Usage: \n"
echo -e "  sh licenseServer.sh [licenseDir port] \n"
echo "    licenseDir - the directory containing the license files."
echo -e "    port - the port of the license server \n"
echo "    If no argument is given, the default location - if this licenseDir parameter is missing - is \"license\" and the default port is \"12346\"."
}

Count=$#
echo Number of arguments passed: $Count

if [ $Count = 0 ]; then
echo "No arguments are given - the default location is \"license\" and the default port is \"12346\"."
startLicenseServer
elif [ $Count = 1 ]; then
showUsage
elif [ $Count = 2 ]; then
startLicenseServer $1 $2
else
showUsage
fi
